<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="no" sourcelanguage="en">
  <context>
    <name>CmdRobotAddToolShape</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="+215"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Add tool</source>
      <translation>Legg til verktøy</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Add a tool shape to the robot</source>
      <translation>Legg til en verktøyform til roboten</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+158"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Place robot...</source>
      <translation>Plasser robot...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Place a robot (experimental!)</source>
      <translation>Plasser en robot (eksperimentell!)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotCreateTrajectory</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="+61"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create trajectory</source>
      <translation>Lag bane</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a new empty trajectory </source>
      <translation>Lag en ny tom bane </translation>
    </message>
  </context>
  <context>
    <name>CmdRobotEdge2Trac</name>
    <message>
      <location line="+257"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Edge to Trajectory...</source>
      <translation>Kant til bane...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Generate a Trajectory from a set of edges</source>
      <translation>Generer en bane fra et sett med kanter</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaCompact</name>
    <message>
      <location filename="../../CommandExport.cpp" line="+50"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka compact subroutine...</source>
      <translation>Kompakt KUKA delrutine...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export the trajectory as a compact KRL subroutine.</source>
      <translation>Eksportere banen som en kompakt KRL delrutine.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaFull</name>
    <message>
      <location line="+63"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka full subroutine...</source>
      <translation>Fullstendig KUKA delrutine...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export the trajectory as a full KRL subroutine.</source>
      <translation>Eksporter banen som en fullstendig KRL delrutine.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR125</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="-43"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka IR125</source>
      <translation>Kuka IR125</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a Kuka IR125 into the document.</source>
      <translation>Sett inn en Kuka IR125 i dokumentet.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR16</name>
    <message>
      <location line="-83"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka IR16</source>
      <translation>Kuka IR16</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a Kuka IR16 into the document.</source>
      <translation>Sett inn en Kuka IR16 i dokumentet.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR210</name>
    <message>
      <location line="+39"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka IR210</source>
      <translation>Kuka IR210</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a Kuka IR210 into the document.</source>
      <translation>Sett inn en Kuka IR210 i dokumentet.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR500</name>
    <message>
      <location line="-85"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka IR500</source>
      <translation>Kuka IR500</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a Kuka IR500 into the document.</source>
      <translation>Sett inn en Kuka IR500 i dokumentet.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypoint</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="-228"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert in trajectory</source>
      <translation>Sett inn i bane</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert robot Tool location into trajectory</source>
      <translation>Sett inn robotverktøy i banen</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypointPreselect</name>
    <message>
      <location line="+55"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert in trajectory</source>
      <translation>Sett inn i bane</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert preselection position into trajectory (W)</source>
      <translation>Sett inn forvalgt posisjon i bane (W)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotRestoreHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="-56"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Move to home</source>
      <translation>Flytt til utgangsposisjon</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultOrientation</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="+62"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Set default orientation</source>
      <translation>Angi standardorientering</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set the default orientation for subsequent commands for waypoint creation</source>
      <translation>sett standardorientering for etterfølgende kommandoer ved veipunktopprettelse</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultValues</name>
    <message>
      <location line="+37"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Set default values</source>
      <translation>Angi standardverdier</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</source>
      <translation>angi standardverdier for hastighet, akselerasjon og kontinuitet for etterfølgende kommandoer ved veipunktetablering</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="-51"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Set the home position</source>
      <translation>Sett utgangsposisjon</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSimulate</name>
    <message>
      <location line="+142"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Simulate a trajectory</source>
      <translation>Simuler en bane</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Run a simulation on a trajectory</source>
      <translation>Kjør simulering på en bane</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryCompound</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="+175"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trajectory compound...</source>
      <translation>Banesammensetning...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Group and connect some trajectories to one</source>
      <translation>Gruppér og koble flere baner til en</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryDressUp</name>
    <message>
      <location line="-49"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Dress up trajectory...</source>
      <translation>Bekledningsbane...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a dress up object which overide som aspects of a trajectory</source>
      <translation>Lag et bekledningsobjekt som oversyrer deler av en bane</translation>
    </message>
  </context>
  <context>
    <name>Gui::TaskView::TaskWatcherCommands</name>
    <message>
      <location filename="../../Workbench.cpp" line="+52"/>
      <source>Trajectory tools</source>
      <translation>Baneverktøy</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Robot tools</source>
      <translation>Robotverktøy</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert Robot</source>
      <translation>Sett inn Robot</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="-126"/>
      <location line="+49"/>
      <location line="+100"/>
      <location line="+29"/>
      <location filename="../../CommandExport.cpp" line="-52"/>
      <location line="+65"/>
      <location filename="../../CommandInsertRobot.cpp" line="+181"/>
      <location filename="../../CommandTrajectory.cpp" line="-276"/>
      <location line="+56"/>
      <location line="+17"/>
      <location line="+229"/>
      <source>Wrong selection</source>
      <translation>Feil valg</translation>
    </message>
    <message>
      <location line="-28"/>
      <location line="+29"/>
      <location filename="../../CommandExport.cpp" line="-64"/>
      <location line="+65"/>
      <location filename="../../CommandTrajectory.cpp" line="-301"/>
      <source>Select one Robot and one Trajectory object.</source>
      <translation>Velg en Robot og ett baneobjekt.</translation>
    </message>
    <message>
      <location line="-24"/>
      <source>Trajectory not valid</source>
      <translation>Banen ikke gyldig</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>You need at least two way points in a trajectory to simulate.</source>
      <translation>Du trenger minst to etappemål i en bane å simulere.</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="-43"/>
      <location line="+65"/>
      <source>KRL file(*.src)</source>
      <translation>KRL fil(*.src)</translation>
    </message>
    <message>
      <location line="-64"/>
      <location line="+65"/>
      <source>All Files (*.*)</source>
      <translation>Alle filer (*.*)</translation>
    </message>
    <message>
      <location line="-64"/>
      <location line="+65"/>
      <source>Export program</source>
      <translation>Eksporter program</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="+1"/>
      <source>Select one robot and one shape or VRML object.</source>
      <translation>Velg en robot og en figur eller et VRML objekt.</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="+79"/>
      <source>No preselection</source>
      <translation>Ingen forvalg</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</source>
      <translation>Du må holde mus over noe geometri (Forvalg) for å bruke denne kommandoen. Se dokumentasjonen for detaljer.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-155"/>
      <source>Select one Robot to set home postion</source>
      <translation>Velg en robot å sette i utgangsposisjon</translation>
    </message>
    <message>
      <location line="+49"/>
      <source>Select one Robot</source>
      <translation>Velg en robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="-24"/>
      <location line="+17"/>
      <source>Select one Trajectory object.</source>
      <translation>Velg ett baneobjekt.</translation>
    </message>
    <message>
      <location line="+84"/>
      <source>set default speed</source>
      <translation>angi standardhastighet</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>speed: (e.g. 1 m/s or 3 cm/s)</source>
      <translation>hastighet: (f.eks 1m/s eller 3cm/s)</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>set default continuity</source>
      <translation>sett standardkontinuitet</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>continuous ?</source>
      <translation>kontinuerlig?</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>set default acceleration</source>
      <translation>sett standardakselerasjon</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</source>
      <translation>akselerasjon: (f.eks 1m/s^2 eller 3cm/s^2)</translation>
    </message>
    <message>
      <location line="+127"/>
      <source>Select the Trajectory which you want to dress up.</source>
      <translation>Select the Trajectory which you want to dress up.</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="+26"/>
      <source>No robot files installed</source>
      <translation>Ingen robot filer installert</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please visit %1 and copy the files to %2</source>
      <translation>Vennligst besøk %1 og kopier filer til %2</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::DlgTrajectorySimulate</name>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="+20"/>
      <source>Simulation</source>
      <translation>Simulering</translation>
    </message>
    <message>
      <location line="+38"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>||</source>
      <translation>||</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>%</source>
      <translation>%</translation>
    </message>
    <message>
      <location line="+35"/>
      <source>Type</source>
      <translation>Type</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Name</source>
      <translation>Navn</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>A</source>
      <translation>A</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.cpp" line="+47"/>
      <source>TaskEdge2TracParameter</source>
      <translation>OppgKantTBaneParameter</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobot6Axis</name>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="+14"/>
      <source>Form</source>
      <translation>Skjema</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>A1</source>
      <translation>A1</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A2</source>
      <translation>A2</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A3</source>
      <translation>A3</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A4</source>
      <translation>A4</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A5</source>
      <translation>A5</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A6</source>
      <translation>A6</translation>
    </message>
    <message>
      <location line="+57"/>
      <source>TCP: (200.23,300.23,400.23,234,343,343)</source>
      <translation>TCP: (200.23,300.23,400.23,234,343,343)</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Tool: (0,0,400,0,0,0)</source>
      <translation>Verktøy: (0,0,400,0,0,0)</translation>
    </message>
    <message>
      <location line="+16"/>
      <source>...</source>
      <translation>...</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.cpp" line="+52"/>
      <source>TaskRobot6Axis</source>
      <translation>OppgaveRobotAkse</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.cpp" line="+46"/>
      <source>TaskRobotControl</source>
      <translation>OppgaveRobotKontroll</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.cpp" line="+46"/>
      <source>TaskRobotMessages</source>
      <translation>OppgaveRobotBeskjeder</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectory</name>
    <message>
      <location filename="../../TaskTrajectory.ui" line="+20"/>
      <source>Form</source>
      <translation>Skjema</translation>
    </message>
    <message>
      <location line="+38"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>||</source>
      <translation>||</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>%</source>
      <translation>%</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>10 ms</source>
      <translation>10 ms</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>50 ms</source>
      <translation>50 ms</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>100 ms</source>
      <translation>100 ms</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>500 ms</source>
      <translation>500 ms</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>1 s</source>
      <translation>1 s</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</source>
      <translation>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Type</source>
      <translation>Type</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Name</source>
      <translation>Navn</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>A</source>
      <translation>A</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.cpp" line="+44"/>
      <source>Trajectory</source>
      <translation>Bane</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.cpp" line="+48"/>
      <source>Dress Up Parameter</source>
      <translation>Bekledningsparameter</translation>
    </message>
  </context>
  <context>
    <name>TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="+14"/>
      <source>Form</source>
      <translation>Skjema</translation>
    </message>
    <message>
      <location line="+15"/>
      <source>Hide / Show</source>
      <translation>Skjul/ Vis</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Edges: 0</source>
      <translation>Kanter: 0</translation>
    </message>
    <message>
      <location line="+14"/>
      <source>Cluster: 0</source>
      <translation>Klynge: 0</translation>
    </message>
    <message>
      <location line="+11"/>
      <source>Sizing Value:</source>
      <translation>Størrelseverdi:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Use orientation of edge</source>
      <translation>Bruk retningen på kanten</translation>
    </message>
    <message>
      <source>TaskEdge2TracParameter</source>
      <translation type="obsolete">OppgKantTBaneParameter</translation>
    </message>
  </context>
  <context>
    <name>TaskRobot6Axis</name>
    <message>
      <source>TaskRobot6Axis</source>
      <translation type="obsolete">OppgaveRobotAkse</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.ui" line="+14"/>
      <source>Form</source>
      <translation>Skjema</translation>
    </message>
    <message>
      <location line="+23"/>
      <source>X+</source>
      <translation>X+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>Y+</source>
      <translation>Y+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>Z+</source>
      <translation>Z+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>A+</source>
      <translation>A+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>B+</source>
      <translation>B+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>C+</source>
      <translation>C+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>X-</source>
      <translation>X-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>Y-</source>
      <translation>Y-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>Z-</source>
      <translation>Z-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>A-</source>
      <translation>A-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>B-</source>
      <translation>B-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>C-</source>
      <translation>C-</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Tool 0</source>
      <translation>Verktøy 0</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Tool</source>
      <translation>Verktøy</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Base 0</source>
      <translation>Base 0</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Base</source>
      <translation>Base</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>World</source>
      <translation>Verden</translation>
    </message>
    <message utf8="true">
      <location line="+9"/>
      <source>50mm / 5°</source>
      <translation>50mm/ 5°</translation>
    </message>
    <message utf8="true">
      <location line="+5"/>
      <source>20mm / 2°</source>
      <translation>20mm/ 2°</translation>
    </message>
    <message utf8="true">
      <location line="+5"/>
      <source>10mm / 1°</source>
      <translation>10mm / 1°</translation>
    </message>
    <message utf8="true">
      <location line="+5"/>
      <source>5mm / 0.5°</source>
      <translation>5mm / 0.5°</translation>
    </message>
    <message utf8="true">
      <location line="+5"/>
      <source>1mm / 0.1°</source>
      <translation>1mm / 0.1°</translation>
    </message>
    <message>
      <source>TaskRobotControl</source>
      <translation type="obsolete">OppgaveRobotKontroll</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.ui" line="+14"/>
      <source>Form</source>
      <translation>Skjema</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>clear</source>
      <translation>fjern</translation>
    </message>
    <message>
      <source>TaskRobotMessages</source>
      <translation type="obsolete">OppgaveRobotBeskjeder</translation>
    </message>
  </context>
  <context>
    <name>TaskTrajectory</name>
    <message>
      <source>Trajectory</source>
      <translation type="obsolete">Bane</translation>
    </message>
  </context>
  <context>
    <name>TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="+14"/>
      <source>Form</source>
      <translation>Skjema</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Speed &amp; Acceleration:</source>
      <translation>Hastighet &amp; akselerasjon:</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Speed:</source>
      <translation>Hastighet:</translation>
    </message>
    <message>
      <location line="+26"/>
      <location line="+37"/>
      <source>Use</source>
      <translation>Bruk</translation>
    </message>
    <message>
      <location line="-26"/>
      <source>Accel:</source>
      <translation>Akselér:</translation>
    </message>
    <message>
      <location line="+36"/>
      <source>Don't change Cont</source>
      <translation>Ikke endre forts</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Continues</source>
      <translation>Fortsetter</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Discontinues</source>
      <translation>Avbryter</translation>
    </message>
    <message>
      <location line="+15"/>
      <source>Position and Orientation:</source>
      <translation>Posisjon og orientering:</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>(0,0,0),(0,0,0)</source>
      <translation>(0,0,0),(0,0,0)</translation>
    </message>
    <message>
      <location line="+13"/>
      <source>...</source>
      <translation>...</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Don't change Position &amp; Orientation</source>
      <translation>Ikke endre posisjon og orientering</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Use Orientation</source>
      <translation>Bruk Orientering</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Add Position</source>
      <translation>Legg til posisjon</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Add Orientation</source>
      <translation>Legg til orientering</translation>
    </message>
    <message>
      <source>Dress Up Parameter</source>
      <translation type="obsolete">Bekledningsparameter</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="-33"/>
      <source>Robot</source>
      <translation>Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert Robots</source>
      <translation>Sett inn Roboter</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Robot</source>
      <translation>&amp;Robot</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export trajectory</source>
      <translation>Eksporter bane</translation>
    </message>
  </context>
</TS>
